       type sternh 
       sequence
            real*8 a   
            real*8 b
            real*8 c
            real*8 x0
            real*8 x1
            real*8 sa
!            real*8 xa   not used from 8.80
            real*8 k      !=m;  from 8.80 old one was always 3
	    real*8 delta0   ! from 8.80
!   
            real*8 tcut 
            real*8 w0
!            real*8 wlg0  ! not used so far so commentout v9.154
       end type sternh
